Learn R Programming

spatstat.explore (version 3.8-0)

Gdot.inhom: Inhomogeneous Multitype G Dot Function

Description

For a multitype point pattern, estimate the inhomogeneous version of the dot \(G\) function, which is the distribution of the distance from a point of type \(i\) to the nearest other point of any type, adjusted for spatially varying intensity.

Usage

Gdot.inhom(X, i,
              lambdaI = NULL, lambdadot = NULL, lambdamin = NULL,
              ...,
              r = NULL, rmax=NULL,
              ReferenceMeasureMarkSetI = NULL, ratio = FALSE)

Arguments

Value

An object of class "fv" (see fv.object) containing estimates of the inhomogeneous dot type \(G\) function.

Details

This is a generalisation of the function Gdot to include an adjustment for spatially inhomogeneous intensity, in a manner similar to the function Ginhom.

The argument lambdaI supplies the values of the intensity of the sub-process of points of type i. It may be either

a pixel image

(object of class "im") which gives the values of the type i intensity at all locations in the window containing X;

a numeric vector

containing the values of the type i intensity evaluated only at the data points of type i. The length of this vector must equal the number of type i points in X.

a function

of the form function(x,y) which can be evaluated to give values of the intensity at any locations.

a fitted point process model

(object of class "ppm", "kppm" or "dppm") whose fitted trend can be used as the fitted intensity. (If update=TRUE the model will first be refitted to the data X before the trend is computed.)

omitted:

if lambdaI is omitted then it will be estimated using a leave-one-out kernel smoother.

If lambdaI is omitted, then it will be estimated using a `leave-one-out' kernel smoother.

Similarly the argument lambdadot should contain estimated values of the intensity of the entire point process. It may be either a pixel image, a numeric vector of length equal to the number of points in X, a function, or omitted.

The argument r is the vector of values for the distance \(r\) at which \(G_{i\bullet}(r)\) should be evaluated. The values of \(r\) must be increasing nonnegative numbers and the maximum \(r\) value must not exceed the radius of the largest disc contained in the window.

References

Cronie, O. and Van Lieshout, M.N.M. (2015) Summary statistics for inhomogeneous marked point processes. Annals of the Institute of Statistical Mathematics DOI: 10.1007/s10463-015-0515-z

See Also

Gdot, Ginhom, Gcross.inhom, Gmulti.inhom.

Examples

Run this code
  X <- rescale(amacrine)
  if(interactive() && require(spatstat.model)) {
    ## how to do it normally
    mod <- ppm(X ~ marks * x)
    lam <- fitted(mod, dataonly=TRUE)
    lmin <- min(predict(mod)[["off"]]) * 0.9
  } else {
    ## for package testing 
    lam <- intensity(X)[as.integer(marks(X))]
    lmin <- intensity(X)[2] * 0.9
  }
  lamI <- lam[marks(X) == "on"]
  GD <- Gdot.inhom(X, "on", lambdaI=lamI, lambdadot=lam, lambdamin=lmin)

Run the code above in your browser using DataLab