Learn R Programming

spatstat.explore (version 3.8-0)

ISE.envelope: Integrated Squared Error on an Envelope Object

Description

Compute integrated squared error of each of the simulated function estimates in an envelope object.

Usage

ISE.envelope(object, theo, domain, dimension=2)

Arguments

Value

A numeric vector of length equal to the number of simulated functions.

Details

The first argument should be an object of class "envelope" and should contain the simulated function estimates (i.e. it should have been computed using envelope with savefuns=TRUE).

The simulated function estimates are extracted from object, and their squared error from the true value theo is computed pointwise. The squared errors are integrated over the interval specified by domain, giving one value of integrated squared error for each simulated function estimate. These values are returned as a numerical vector.

See Also

bias.envelope, MISE.envelope.

Examples

Run this code
  E <- envelope(cells, Kest, correction="translate", nsim=20, savefuns=TRUE)
  theoK <- function(r) { pi * r^2 }
  dom <- c(0, 0.1)
  ISE.envelope(E, theoK, dom)

Run the code above in your browser using DataLab