The functions Kmark and markcorrint are identical.
(Eventually markcorrint will be deprecated.)
The mark-weighted \(K\) function \(K_f(r)\)
of a marked point process (Penttinen et al, 1992)
is a generalisation of Ripley's \(K\) function, in which the contribution
from each pair of points is weighted by a function of their marks.
If the marks of the two points are \(m_1, m_2\) then
the weight is proportional to \(f(m_1, m_2)\) where
\(f\) is a specified test function.
The mark-weighted \(K\) function is defined so that
$$
\lambda K_f(r) = \frac{C_f(r)}{E[ f(M_1, M_2) ]}
$$
where
$$
C_f(r) =
E \left[
\sum_{x \in X}
f(m(u), m(x))
1{0 < ||u - x|| \le r}
\; \big| \;
u \in X
\right]
$$
for any spatial location \(u\) taken to be a typical point of
the point process \(X\). Here \(||u-x||\) is the
euclidean distance between \(u\) and \(x\), so that the sum
is taken over all random points \(x\) that lie within a distance
\(r\) of the point \(u\). The function \(C_f(r)\) is
the unnormalised mark-weighted \(K\) function.
To obtain \(K_f(r)\) we standardise \(C_f(r)\)
by dividing by \(E[f(M_1,M_2)]\), the expected value of
\(f(M_1,M_2)\) when \(M_1\) and \(M_2\) are
independent random marks with the same distribution as the marks in
the point process.
Under the hypothesis of random labelling, the
mark-weighted \(K\) function
is equal to Ripley's \(K\) function,
\(K_f(r) = K(r)\).
The mark-weighted \(K\) function is sometimes called the
mark correlation integral because it is related to the
mark correlation function \(k_f(r)\)
and the pair correlation function \(g(r)\) by
$$
K_f(r) = 2 \pi \int_0^r s k_f(s) \, g(s) \, {\rm d}s
$$
See markcorr for a definition of the
mark correlation function.
Given a marked point pattern X,
this command computes edge-corrected estimates
of the mark-weighted \(K\) function.
If returnL=FALSE then the estimated
function \(K_f(r)\) is returned;
otherwise the function
$$
L_f(r) = \sqrt{K_f(r)/\pi}
$$
is returned.