powered by
Generic function to perform spatial smoothing of spatial data by diffusion.
SmoothHeat(X, ...)
An object containing smoothed values of the input data, in an appropriate format. See the documentation for the methods.
This generic function calls an appropriate method to perform spatial smoothing on the spatial dataset X using diffusion.
X
Methods for this function include
SmoothHeat.ppp for point patterns
SmoothHeat.ppp
SmoothHeat.im for pixel images.
SmoothHeat.im
SmoothHeat.ppp, SmoothHeat.im.