Learn R Programming

spatstat.explore (version 3.8-0)

SmoothHeat.ppp: Spatial Smoothing of Observations using Diffusion Estimate of Density

Description

Performs spatial smoothing of numeric values observed at a set of irregular locations, using the diffusion estimate of the density.

Usage

# S3 method for ppp
SmoothHeat(X, sigma, ..., weights=NULL)

Arguments

Value

Pixel image (object of class "im") giving the smoothed mark value.

Details

This is the analogue of the Nadaraya-Watson smoother, using the diffusion smoothing estimation procedure (Baddeley et al, 2022). The numerator and denominator of the Nadaraya-Watson smoother are calculated using densityHeat.ppp.

References

Baddeley, A., Davies, T., Rakshit, S., Nair, G. and McSwiggan, G. (2022) Diffusion smoothing for spatial point patterns. Statistical Science 37, 123--142.

See Also

Smooth.ppp for the usual kernel-based smoother (the Nadaraya-Watson smoother) and densityHeat for the diffusion estimate of density.

Examples

Run this code
   plot(SmoothHeat(longleaf, 10))

Run the code above in your browser using DataLab