powered by
Extract a subset of the data for a spatially sampled function.
# S3 method for ssf [(x, i, j, ..., drop)
Another object of class "ssf".
"ssf"
This is the subset operator for the class "ssf".
ssf, with.ssf
ssf
with.ssf
f <- ssf(cells, data.frame(d=nndist(cells), i=1:42)) f f[1:10,] f[ ,1]
Run the code above in your browser using DataLab