powered by
Computes a kernel smoothed estimate of the probability density for angular data.
circdensity(x, sigma = "nrd0", ..., bw = NULL, weights=NULL, unit = c("degree", "radian", "hour", "minute", "other"), fullcircle=NULL)
An object of class "density" (produced by
"density"
density.default) which can be plotted by plot or by rose.density.
density.default
plot
rose.density
The result also contains information about the arguments
unit and fullcircle which can be used by
unit
fullcircle
rose.density.
Numeric vector, containing angular data.
Smoothing bandwidth, or bandwidth selection rule, passed to density.default.
Alternative to sigma for consistency with other functions.
sigma
Additional arguments passed to density.default, such as kernel and weights.
kernel
weights
Optional numeric vector of weights for the data in x.
x
The unit of angle in which x is expressed. Character string (partially matched).
The period (the value of x that corresponds to one full circle) if unit="other".
unit="other"
Adrian Baddeley Adrian.Baddeley@curtin.edu.au, Rolf Turner rolfturner@posteo.net and Ege Rubak rubak@math.aau.dk.
The angular values x are smoothed using (by default) the wrapped Gaussian kernel with standard deviation sigma.
density.default), rose.
rose
ang <- runif(1000, max=360) rose(circdensity(ang, 12))
Run the code above in your browser using DataLab