The Clark and Evans (1954) aggregation index \(R\) is a crude
measure of clustering or ordering of a point pattern.
It is the ratio of the observed mean nearest neighbour distance
in the pattern to that expected for a Poisson point process
of the same intensity.
A value \(R>1\) suggests ordering, while \(R<1\) suggests
clustering.
Without correction for edge effects, the value of R will be
positively biased. Edge effects arise because, for a point of X
close to the edge of the window, the true nearest neighbour may
actually lie outside the window. Hence observed nearest neighbour
distances tend to be larger than the true nearest neighbour distances.
The argument correction specifies an edge correction
or several edge corrections to be applied. It is a character vector
containing one or more of the options
"none", "Donnelly", "guard" and "cdf"
(which are recognised by partial matching).
These edge corrections are:
- "none":
No edge correction is applied.
- "Donnelly":
Edge correction of Donnelly (1978), available for rectangular
windows only.
The theoretical expected value of mean nearest neighbour distance
under a Poisson process is adjusted for edge effects by the
edge correction of Donnelly (1978). The value of \(R\) is the
ratio of the observed mean nearest neighbour distance to this
adjusted theoretical mean.
- "guard":
Guard region or buffer area method.
The observed mean nearest neighbour distance
for the point pattern X
is re-defined by averaging only over those points of X
that fall inside the sub-window clipregion.
- "cdf":
Cumulative Distribution Function method.
The nearest neighbour distance distribution function \(G(r)\)
of the stationary point process is estimated by Gest
using the Kaplan-Meier type edge correction. Then the mean of the
distribution is calculated from the cdf.
Alternatively correction="all" selects all options.
If the argument clipregion is given, then the selected
edge corrections will be assumed to include correction="guard".
To perform a test based on the Clark-Evans index,
see clarkevans.test.