T. F. Cox (1979) proposed a method for identifying
dense and sparse regions in a forest stand.
Each spatial location \(u\) is classified as
belonging to the “clumped” region if
\(T_n(u) < d_n\), or
belonging to the “sparse” region if
\(T_n(u) > c_n\), and otherwise belonging
to neither the clumped nor the sparse regions.
Here \(d_n,c_n\) are constants depending on
n and alpha, and
\(T_n(u)\) is the statistic
$$
T_n(u) = b_2 + b_1 \overline\lambda \pi \sum_{k=1}^n R_k(u)^2
$$
where \(b_1,b_2\) are constants depending on n,
\(\overline\lambda\) is the estimated intensity
(number of points of X divided by area of the window of
X), and \(R_k(u)\) is the distance from \(u\)
to the \(k\)-th nearest point of X.
This function evaluates \(T_n(u)\) at each pixel location
\(u\) in a grid, and classifies each pixel as belonging to the
clumped, sparse or intermediate regions. The result is a pixel image
with categorical values giving the classification.