Learn R Programming

spatstat.explore (version 3.8-0)

dg.envelope: Global Envelopes for Dao-Genton Test

Description

Computes the global envelopes corresponding to the Dao-Genton test of goodness-of-fit.

Usage

dg.envelope(X, ...,
            nsim = 19, nsimsub=nsim-1, nrank = 1,
            alternative=c("two.sided", "less", "greater"),
            leaveout=1, interpolate = FALSE,
            savefuns=FALSE, savepatterns=FALSE,
            verbose = TRUE)

Arguments

Value

An object of class "fv".

Details

Computes global simulation envelopes corresponding to the Dao-Genton (2014) adjusted Monte Carlo goodness-of-fit test. The envelopes were developed in Baddeley et al (2015) and described in Baddeley, Rubak and Turner (2015).

If X is a point pattern, the null hypothesis is CSR.

If X is a fitted model, the null hypothesis is that model.

The Dao-Genton test is biased when the significance level is very small (small \(p\)-values are not reliable) and we recommend bits.envelope in this case.

References

Dao, N.A. and Genton, M. (2014) A Monte Carlo adjusted goodness-of-fit test for parametric models describing spatial point patterns. Journal of Graphical and Computational Statistics 23, 497--517.

Baddeley, A., Hardegen, A., Lawrence, L., Milne, R.K., Nair, G.M. and Rakshit, S. (2015) Pushing the envelope: extensions of graphical Monte Carlo tests. Unpublished manuscript.

Baddeley, A., Rubak, E. and Turner, R. (2015) Spatial Point Patterns: Methodology and Applications with R. Chapman and Hall/CRC Press.

See Also

dg.test, mad.test, envelope

Examples

Run this code
  ns <- if(interactive()) 19 else 4
  E <- dg.envelope(swedishpines, Lest, nsim=ns)
  E
  plot(E)
  Eo <- dg.envelope(swedishpines, Lest, alternative="less", nsim=ns)
  Ei <- dg.envelope(swedishpines, Lest, interpolate=TRUE, nsim=ns)

Run the code above in your browser using DataLab