Learn R Programming

spatstat.explore (version 3.8-0)

markmarkscatter: Mark-Mark Scatter Plot

Description

Generates the mark-mark scatter plot of a point pattern.

Usage

markmarkscatter(X, rmax, ..., col = NULL, symap = NULL, transform=I, jit=FALSE)

Arguments

Value

Null.

Details

The mark-mark scatter plot (Ballani et al, 2019) is a scatterplot of the mark values of all pairs of distinct points in X which are closer than the distance rmax. The dots in the scatterplot are coloured according to the pairwise distance between the two spatial points. The plot is augmented by three curves explained by Ballani et al (2019).

If the marks only take a few different values, then it is usually appropriate to apply random perturbation (jitter) to the mark values, by setting jit=TRUE.

References

Ballani, F., Pommerening, A. and Stoyan, D. (2019) Mark-mark scatterplots improve pattern analysis in spatial plant ecology. Ecological Informatics 49, 13--21.

Examples

Run this code
  markmarkscatter(longleaf, 10)

  markmarkscatter(spruces, 10, jit=TRUE)

Run the code above in your browser using DataLab