This command computes the mean value of
fun(T) where T is
the Euclidean distance \(T = \|X_1 - X_2\|\)
between two independent random points \(X_1\) and \(X_2\).
In the simplest case, the command pairMean(fun, W),
the random points are assumed to be uniformly distributed in the same
window W. Alternatively the two random points may be
uniformly distributed in two different windows W and V.
Other options are described in distcdf.
The algorithm uses distcdf to compute the cumulative
distribution function of T, and stieltjes to
compute the mean value of fun(T).
If normalise=TRUE (the default) the result is the mean value of
fun(T). If normalise=FALSE the result is the double
integral.