Learn R Programming

spatstat.explore (version 3.8-0)

pcfcross.inhom: Inhomogeneous Multitype Pair Correlation Function (Cross-Type)

Description

Estimates the inhomogeneous cross-type pair correlation function for a multitype point pattern.

Usage

pcfcross.inhom(X, i, j, lambdaI = NULL, lambdaJ = NULL, ...)

Value

A function value table (object of class "fv"). Essentially a data frame containing the variables

r

the vector of values of the argument \(r\) at which the inhomogeneous cross-type pair correlation function \(g_{ij}(r)\) has been estimated

theo

vector of values equal to 1, the theoretical value of \(g_{ij}(r)\) for the Poisson process

trans

vector of values of \(g_{ij}(r)\) estimated by translation correction

iso

vector of values of \(g_{ij}(r)\) estimated by Ripley isotropic correction

as required.

Arguments

X

The observed point pattern, from which an estimate of the inhomogeneous cross-type pair correlation function \(g_{ij}(r)\) will be computed. It must be a multitype point pattern (a marked point pattern whose marks are a factor).

i

The type (mark value) of the points in X from which distances are measured. A character string (or something that will be converted to a character string). Defaults to the first level of marks(X).

j

The type (mark value) of the points in X to which distances are measured. A character string (or something that will be converted to a character string). Defaults to the second level of marks(X).

lambdaI

Optional. Values of the estimated intensity function of the points of type i. Either a numeric vector giving the intensity values at the data points of type i, a pixel image (object of class "im") giving the intensity values of points of type i at all locations, a function(x,y) which can be evaluated to give the intensity value of points of type i at any location, a fitted multitype point process model (class "ppm") which could be used to predict the intensity values of points of each type at any location, or a fitted unmarked point process model (class "ppm", "kppm", "dppm" or "slrm") which could be used to predict the intensity values of points of type i only at any location.

lambdaJ

Optional. Values of the estimated intensity function of the points of type j. Numeric vector, pixel image, function(x,y) or fitted point process model.

...

Arguments passed to pcfmulti.inhom to control the computation.

Author

Adrian Baddeley Adrian.Baddeley@curtin.edu.au, Rolf Turner rolfturner@posteo.net, Ege Rubak rubak@math.aau.dk, Tilman Davies Tilman.Davies@otago.ac.nz and Martin Hazelton Martin.Hazelton@otago.ac.nz.

Details

The inhomogeneous cross-type pair correlation function \(g_{ij}(r)\) is a summary of the dependence between two types of points in a multitype spatial point process that does not have a uniform density of points.

The best intuitive interpretation is the following: the probability \(p(r)\) of finding two points, of types \(i\) and \(j\) respectively, at locations \(x\) and \(y\) separated by a distance \(r\) is equal to $$ p(r) = \lambda_i(x) lambda_j(y) g(r) \,{\rm d}x \, {\rm d}y $$ where \(\lambda_i\) is the intensity function of the process of points of type \(i\). For a multitype Poisson point process, this probability is \(p(r) = \lambda_i(x) \lambda_j(y)\) so \(g_{ij}(r) = 1\).

The command pcfcross.inhom estimates the inhomogeneous pair correlation using a modified version of the algorithm in pcf.ppp. The arguments bw and adjust.bw control the degree of one-dimensional smoothing of the estimate of pair correlation.

If the arguments lambdaI and/or lambdaJ are missing or null, they will be estimated from X by spatial kernel smoothing using a leave-one-out estimator, computed by density.ppp. The arguments sigma, varcov and adjust.sigma control the degree of spatial smoothing.

See Also

pcf.ppp, pcfinhom, pcfcross, pcfdot.inhom

Examples

Run this code
  plot(pcfcross.inhom(amacrine, "on", "off", stoyan=0.1),
       legendpos="bottom")

Run the code above in your browser using DataLab