View source: R/pcfmulti.inhom.R
| pcfmulti.inhom | R Documentation |
Estimates the inhomogeneous multitype pair correlation function for a multitype point pattern.
pcfmulti.inhom(X, I, J, lambdaI = NULL, lambdaJ = NULL, ...,
lambdaX=NULL,
r = NULL, breaks = NULL, rmax = NULL,
adaptive = FALSE,
kernel = "epanechnikov", bw = NULL, h = NULL, bw.args = list(),
stoyan = 0.15, adjust.bw = 1,
correction = c("translate", "Ripley"),
divisor = c("a", "r", "d", "t"),
zerocor = c("convolution", "reflection",
"bdrykern", "JonesFoster", "weighted",
"none", "good", "best"),
nsmall = 300,
gref = NULL, tau = 0,
sigma = NULL, adjust.sigma = 1, varcov = NULL,
update = TRUE, leaveoneout = TRUE,
Iname = "points satisfying condition I",
Jname = "points satisfying condition J",
IJexclusive = FALSE, Ilevels=NULL, Jlevels=NULL,
close = NULL)
X |
The observed point pattern,
from which an estimate of the inhomogeneous
cross-type pair correlation function
|
I |
Subset index specifying the points of |
J |
Subset index specifying the points in |
lambdaI |
Optional.
Values of the estimated intensity function of the points
belonging to subset |
lambdaJ |
Optional.
Values of the estimated intensity function of the points
belonging to subset |
... |
Ignored. |
lambdaX |
Optional.
Alternative to |
r |
Vector of values for the argument |
breaks |
Internal use only. |
rmax |
Optional. Maximum desired value of the argument |
adaptive |
Logical value specifying whether to use adaptive kernel smoothing
( |
kernel |
Choice of smoothing kernel,
passed to |
bw |
Bandwidth for smoothing kernel. Either a single numeric value giving the standard deviation of the kernel, or a character string specifying a bandwidth selection rule, or a function that computes the selected bandwidth. See Details. |
h |
Kernel halfwidth |
bw.args |
Optional. List of additional arguments to be passed to |
stoyan |
Coefficient for default bandwidth rule. |
adjust.bw |
Numerical adjustment factor for the bandwidth.
The bandwidth actually used is |
correction |
String (partially matched) specifying the choice or choices
of spatial edge correction. Options include |
divisor |
String specifying the choice of estimator.
See |
zerocor |
String (partially matched) specifying a correction for the boundary effect
bias at |
nsmall |
Optional. Integer. The maximum number of data points
for which the default value of |
gref |
Optional. A pair correlation function that will be used as the
reference for the transformation to uniformity, when
|
tau |
Optional shrinkage coefficient. A single numeric value. |
sigma, varcov |
Optional arguments passed to |
adjust.sigma |
Numeric value. |
update |
Logical value indicating what to do when
|
leaveoneout |
Logical value (passed to |
Iname, Jname |
Optional. Character strings describing the members of
the subsets |
IJexclusive |
Logical value indicating whether the subsets |
Ilevels |
Character vector containing the types of points
(levels of |
Jlevels |
Character vector containing the types of points
(levels of |
close |
Advanced use only.
Precomputed data obtained from |
This is a generalisation of pcfcross.inhom
to arbitrary collections of points.
The algorithm measures the distance from each data point
in subset I to each data point in subset J,
excluding identical pairs of points. The distances are
weighted by the reciprocal intensity (as described below), then
kernel-smoothed and renormalised to form a pair correlation
function.
The contribution from each pair of data points u,v is weighted by
1/(\lambda_I(u) \lambda_J(v))
where \lambda_I(u) is the estimated intensity
of points belonging to subset I at location u,
and similarly \lambda_J(u) is the estimated intensity
of points belonging to subset J at location v.
The estimated intensities \lambda_I(u)
and \lambda_J(u) are determined as follows.
If lambdaX is given, then it should
provide data giving the intensities of both subsets I and
J. It may be
A list of pixel images, one for each possible type of point
A function(x,y,mark) which can be evaluated to
give the intensity of each type of point at any location
A matrix with one row for each data point in X
and one column for each possible type of point, giving the estimated
intensity of each type of point at each data location
A fitted point process model (class "lppm" or "ppm")
that was fitted to a multitype point pattern. If
update=TRUE, this model will be re-fitted to the data
pattern X. Then the fitted intensities for subsets I and
J will be computed (using the information Ilevels
and Jlevels).
Otherwise if lambdaI is given, it may be
A pixel image
A function(x,y)
A numeric vector with one entry for each data point in X[I]
A fitted point process model (class "lppm" or "ppm")
that was fitted to a multitype point pattern. If
update=TRUE, this model will be re-fitted to the data
pattern X. Then the intensity of this model for
the subset I will be computed (using the information
Ilevels).
A fitted point process model
(class "lppm", "ppm", "kppm", "dppm" or "slrm")
that was fitted to an unmarked point pattern. If
update=TRUE, this model will be re-fitted to the relevant subset of
the data, unmark(X[I]). Then the intensity of this fitted model
will be computed.
Otherwise if lambda is missing or NULL,
then a kernel estimate of the intensity
\lambda_I(u)
will be computed by applying density.ppp
to X[I] using the arguments
sigma, adjust.sigma, varcov
and leaveoneout.
Similarly for lambdaJ.
The smoothing algorithm is a multitype version of the
smoothing algorithm in pcf.ppp.
See pcf.ppp for detailed documentation of the arguments
correction, divisor, zerocor,
and other smoothing arguments.
An object of class "fv".
, \tilman and \martinH.
pcfcross.inhom,
pcf.ppp.
adult <- (marks(longleaf) >= 30)
juvenile <- !adult
p <- pcfmulti.inhom(longleaf, adult, juvenile)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.