Given a point pattern \(X\) and predictor variables
\(Z_1, \dots, Z_p\),
Sufficient Dimension Reduction methods
(Guan and Wang, 2010) attempt to find a minimal set
of new predictor variables, each constructed by taking a linear combination
of the original predictors, which explain the dependence of
\(X\) on \(Z_1, \dots, Z_p\).
The methods do not assume any particular form of dependence
of the point pattern on the predictors.
The predictors are assumed to
be Gaussian random fields.
Available methods are:
method="DR" | directional regression |
method="NNIR" | nearest neighbour inverse regression |
method="SAVE" | sliced average variance estimation |
method="SIR" | sliced inverse regression |
method="TSE" | two-step estimation |
The result includes a matrix B whose columns are estimates
of the basis vectors of the space of new predictors. That is,
the jth column of B expresses the jth new
predictor as a linear combination of the original predictors.
If predict=TRUE, the new predictors are also evaluated.
They can also be evaluated using sdrPredict.