This is a generalisation of the function Gdot
to include an adjustment for spatially inhomogeneous intensity,
in a manner similar to the function Ginhom.
The argument lambdaI supplies the values
of the intensity of the sub-process of points of type i.
It may be either
- a pixel image
(object of class "im") which
gives the values of the type i intensity
at all locations in the window containing X;
- a numeric vector
containing the values of the
type i intensity evaluated only
at the data points of type i. The length of this vector
must equal the number of type i points in X.
- a function
of the form function(x,y)
which can be evaluated to give values of the intensity at
any locations.
- a fitted point process model
(object of class "ppm", "kppm" or "dppm")
whose fitted trend can be used as the fitted intensity.
(If update=TRUE the model will first be refitted to the
data X before the trend is computed.)
- omitted:
if lambdaI is omitted then it will be estimated
using a leave-one-out kernel smoother.
If lambdaI is omitted, then it will be estimated using
a `leave-one-out' kernel smoother.
Similarly the argument lambdadot should contain
estimated values of the intensity of the entire point process.
It may be either a pixel image, a numeric vector of length equal
to the number of points in X, a function, or omitted.
The argument r is the vector of values for the
distance \(r\) at which \(G_{i\bullet}(r)\) should be evaluated.
The values of \(r\) must be increasing nonnegative numbers
and the maximum \(r\) value must not exceed the radius of the
largest disc contained in the window.