powered by
Given a spatial object (such as a point pattern or pixel image) in two dimensions, these functions extract the window in which the object is defined.
# S3 method for quadrattest Window(X, ...)
An object of class "owin" (see owin.object) specifying an observation window.
"owin"
owin.object
These are methods for the generic function Window which extract the spatial window in which the object X is defined.
Window
X
Window, Window.ppp, Window.psp.
Window.ppp
Window.psp
A <- quadrat.test(cells, 4) Window(A)
Run the code above in your browser using DataLab