circdensity: Density Estimation for Circular Data

View source: R/circdensity.R

circdensityR Documentation

Density Estimation for Circular Data

Description

Computes a kernel smoothed estimate of the probability density for angular data.

Usage

circdensity(x, sigma = "nrd0", ...,
               bw = NULL,
               weights=NULL,
               unit = c("degree", "radian", "hour", "minute", "other"),
               fullcircle=NULL)

Arguments

x

Numeric vector, containing angular data.

sigma

Smoothing bandwidth, or bandwidth selection rule, passed to density.default.

bw

Alternative to sigma for consistency with other functions.

...

Additional arguments passed to density.default, such as kernel and weights.

weights

Optional numeric vector of weights for the data in x.

unit

The unit of angle in which x is expressed. Character string (partially matched).

fullcircle

The period (the value of x that corresponds to one full circle) if unit="other".

Details

The angular values x are smoothed using (by default) the wrapped Gaussian kernel with standard deviation sigma.

Value

An object of class "density" (produced by density.default) which can be plotted by plot or by rose.density.

The result also contains information about the arguments unit and fullcircle which can be used by rose.density.

Author(s)

\spatstatAuthors

.

See Also

density.default), rose.

Examples

  ang <- runif(1000, max=360)
  rose(circdensity(ang, 12))

spatstat.explore documentation built on May 24, 2026, 9:07 a.m.