| circdensity | R Documentation |
Computes a kernel smoothed estimate of the probability density for angular data.
circdensity(x, sigma = "nrd0", ...,
bw = NULL,
weights=NULL,
unit = c("degree", "radian", "hour", "minute", "other"),
fullcircle=NULL)
x |
Numeric vector, containing angular data. |
sigma |
Smoothing bandwidth, or bandwidth selection rule, passed to
|
bw |
Alternative to |
... |
Additional arguments passed to
|
weights |
Optional numeric vector of weights for the data in |
unit |
The unit of angle in which |
fullcircle |
The period (the value of |
The angular values x are smoothed using
(by default) the wrapped Gaussian kernel with standard deviation
sigma.
An object of class "density" (produced by
density.default) which can be plotted
by plot or by rose.density.
The result also contains information about the arguments
unit and fullcircle which can be used by
rose.density.
.
density.default),
rose.
ang <- runif(1000, max=360)
rose(circdensity(ang, 12))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.