Given a point pattern, classify the spatial domain into regions where the pattern is dense, sparse, or neither.
coxmap(X, ...)# S3 method for ppp
coxmap(X, n, alpha=0.05, ...)
A pixel image (object of class "im") with factor values,
with possible levels clumped, sparse and neither.
A point pattern (object of class "ppp").
Maximum number of neighbours to consider. An integer greater than 1.
Threshold for upper and lower quantiles. A number strictly between 0 and 1.
Additional arguments passed to as.mask
to determine the pixel resolution.
Adrian Baddeley Adrian.Baddeley@curtin.edu.au.
T. F. Cox (1979) proposed a method for identifying dense and sparse regions in a forest stand.
Each spatial location \(u\) is classified as
belonging to the “clumped” region if
\(T_n(u) < d_n\), or
belonging to the “sparse” region if
\(T_n(u) > c_n\), and otherwise belonging
to neither the clumped nor the sparse regions.
Here \(d_n,c_n\) are constants depending on
n and alpha, and
\(T_n(u)\) is the statistic
$$
T_n(u) = b_2 + b_1 \overline\lambda \pi \sum_{k=1}^n R_k(u)^2
$$
where \(b_1,b_2\) are constants depending on n,
\(\overline\lambda\) is the estimated intensity
(number of points of X divided by area of the window of
X), and \(R_k(u)\) is the distance from \(u\)
to the \(k\)-th nearest point of X.
This function evaluates \(T_n(u)\) at each pixel location \(u\) in a grid, and classifies each pixel as belonging to the clumped, sparse or intermediate regions. The result is a pixel image with categorical values giving the classification.
Cox, T.F. (1979) A method for mapping the dense and sparse regions of a forest stand. Applied Statistics 28, 14--19.
nnclean,
distmap,
nnmap,
quantess
plot(coxmap(redwoodfull, 5))
points(redwoodfull, col="white", cex=0.5)
Run the code above in your browser using DataLab