The functions localKinhom and localLinhom
are inhomogeneous or weighted versions of the
neighbourhood density function implemented in
localK and localL.
Given a spatial point pattern X, the
inhomogeneous neighbourhood density function
\(L_i(r)\) associated with the \(i\)th point
in X is computed by
$$
L_i(r) = \sqrt{\frac 1 \pi \sum_j \frac{e_{ij}}{\lambda_j}}
$$
where the sum is over all points \(j \neq i\) that lie
within a distance \(r\) of the \(i\)th point,
\(\lambda_j\) is the estimated intensity of the
point pattern at the point \(j\),
and \(e_{ij}\) is an edge correction
term (as described in Kest).
The value of \(L_i(r)\) can also be interpreted as one
of the summands that contributes to the global estimate of the
inhomogeneous L function (see Linhom).
By default, the function \(L_i(r)\) or
\(K_i(r)\) is computed for a range of \(r\) values
for each point \(i\). The results are stored as a function value
table (object of class "fv") with a column of the table
containing the function estimates for each point of the pattern
X.
Alternatively, if the argument rvalue is given, and it is a
single number, then the function will only be computed for this value
of \(r\), and the results will be returned as a numeric vector,
with one entry of the vector for each point of the pattern X.