Calculates an estimate of the cross-type pair correlation function for a multitype point pattern.
pcfcross(X, i, j, ...)An object of class "fv", see fv.object,
which can be plotted directly using plot.fv.
Essentially a data frame containing columns
the vector of values of the argument \(r\) at which the function \(g_{i,j}\) has been estimated
the theoretical value \(g_{i,j}(r) = 1\) for independent marks.
together with columns named
"border", "bord.modif",
"iso" and/or "trans",
according to the selected edge corrections. These columns contain
estimates of the function \(g_{i,j}\)
obtained by the edge corrections named.
The observed point pattern, from which an estimate of the cross-type pair correlation function \(g_{ij}(r)\) will be computed. It must be a multitype point pattern (a marked point pattern whose marks are a factor).
The type (mark value)
of the points in X from which distances are measured.
A character string (or something that will be converted to a
character string).
Defaults to the first level of marks(X).
The type (mark value)
of the points in X to which distances are measured.
A character string (or something that will be
converted to a character string).
Defaults to the second level of marks(X).
Arguments passed to pcfmulti
to control the computation.
Adrian Baddeley Adrian.Baddeley@curtin.edu.au and Rolf Turner rolfturner@posteo.net
The cross-type pair correlation function
is a generalisation of the pair correlation function pcf
to multitype point patterns.
For two locations \(x\) and \(y\) separated by a distance \(r\),
the probability \(p(r)\) of finding a point of type \(i\) at location
\(x\) and a point of type \(j\) at location \(y\) is
$$
p(r) = \lambda_i \lambda_j g_{i,j}(r) \,{\rm d}x \, {\rm d}y
$$
where \(\lambda_i\) is the intensity of the points
of type \(i\).
For a completely random Poisson marked point process,
\(p(r) = \lambda_i \lambda_j\)
so \(g_{i,j}(r) = 1\).
Indeed for any marked point pattern in which the points of type i
are independent of the points of type j,
the theoretical value of the cross-type pair correlation is
\(g_{i,j}(r) = 1\).
For a stationary multitype point process, the cross-type pair correlation
function between marks \(i\) and \(j\) is formally defined as
$$
g_{i,j}(r) = \frac{K_{i,j}^\prime(r)}{2\pi r}
$$
where \(K_{i,j}^\prime\) is the derivative of
the cross-type \(K\) function \(K_{i,j}(r)\).
of the point process. See Kest for information
about \(K(r)\).
The command pcfcross computes a kernel estimate of
the cross-type pair correlation function between marks \(i\) and
\(j\).
The companion function pcfdot computes the
corresponding analogue of Kdot.
Mark connection function markconnect.
Multitype pair correlation pcfdot, pcfmulti.
Pair correlation pcf,pcf.ppp.
Kcross
p <- pcfcross(amacrine, "off", "on")
p <- pcfcross(amacrine, "off", "on", stoyan=0.1)
plot(p)
Run the code above in your browser using DataLab