Calculates an estimate of the multitype pair correlation function
(from points of type i to points of any type)
for a multitype point pattern.
pcfdot(X, i, ...)An object of class "fv", see fv.object,
which can be plotted directly using plot.fv.
Essentially a data frame containing columns
the vector of values of the argument \(r\) at which the function \(g_{i\bullet}\) has been estimated
the theoretical value \(g_{i\bullet}(r) = 1\) for independent marks.
together with columns named
"border", "bord.modif",
"iso" and/or "trans",
according to the selected edge corrections. These columns contain
estimates of the function \(g_{i,j}\)
obtained by the edge corrections named.
This is a generalisation of the pair correlation function pcf
to multitype point patterns.
For two locations \(x\) and \(y\) separated by a nonzero distance \(r\), the probability \(p(r)\) of finding a point of type \(i\) at location \(x\) and a point of any type at location \(y\) is $$ p(r) = \lambda_i \lambda g_{i\bullet}(r) \,{\rm d}x \, {\rm d}y $$ where \(\lambda\) is the intensity of all points, and \(\lambda_i\) is the intensity of the points of type \(i\). For a completely random Poisson marked point process, \(p(r) = \lambda_i \lambda\) so \(g_{i\bullet}(r) = 1\).
For a stationary multitype point process, the
type-i-to-any-type pair correlation
function between marks \(i\) and \(j\) is formally defined as
$$
g_{i\bullet}(r) = \frac{K_{i\bullet}^\prime(r)}{2\pi r}
$$
where \(K_{i\bullet}^\prime\) is the derivative of
the type-i-to-any-type \(K\) function
\(K_{i\bullet}(r)\).
of the point process. See Kdot for information
about \(K_{i\bullet}(r)\).
The command pcfdot computes a kernel estimate of
the multitype pair correlation function from points of type \(i\)
to points of any type.
The companion function pcfcross computes the
corresponding analogue of Kcross.
Mark connection function markconnect.
Multitype pair correlation pcfcross, pcfmulti.
Pair correlation pcf,pcf.ppp.
Kdot
p <- pcfdot(amacrine, "on")
p <- pcfdot(amacrine, "on", stoyan=0.1)
plot(p)
Run the code above in your browser using DataLab