Learn R Programming

spatstat.explore (version 3.8-0)

pcfdot.inhom: Inhomogeneous Multitype Pair Correlation Function (Type-i-To-Any-Type)

Description

Estimates the inhomogeneous multitype pair correlation function (from type \(i\) to any type) for a multitype point pattern.

Usage

pcfdot.inhom(X, i, lambdaI = NULL, lambdadot = NULL, ...)

Value

A function value table (object of class "fv"). Essentially a data frame containing the variables

r

the vector of values of the argument \(r\) at which the inhomogeneous multitype pair correlation function \(g_{i\bullet}(r)\) has been estimated

theo

vector of values equal to 1, the theoretical value of \(g_{i\bullet}(r)\) for the Poisson process

trans

vector of values of \(g_{i\bullet}(r)\) estimated by translation correction

iso

vector of values of \(g_{i\bullet}(r)\) estimated by Ripley isotropic correction

as required.

Arguments

X

The observed point pattern, from which an estimate of the inhomogeneous multitype pair correlation function \(g_{i\bullet}(r)\) will be computed. It must be a multitype point pattern (a marked point pattern whose marks are a factor).

i

The type (mark value) of the points in X from which distances are measured. A character string (or something that will be converted to a character string). Defaults to the first level of marks(X).

lambdaI

Optional. Values of the estimated intensity function of the points of type i. Values of the estimated intensity function of the points of type i. Either a numeric vector giving the intensity values at the data points of type i, a pixel image (object of class "im") giving the intensity values of points of type i at all locations, a function(x,y) which can be evaluated to give the intensity value of points of type i at any location, a fitted multitype point process model (class "ppm") which could be used to predict the intensity values of points of each type at any location, or a fitted unmarked point process model (class "ppm", "kppm", "dppm" or "slrm") which could be used to predict the intensity values of points of type i only at any location.

lambdadot

Optional. Values of the estimated intensity function of the point pattern X. A numeric vector, pixel image, function(x,y) or fitted point process model.

...

Arguments passed to pcfmulti.inhom to control the computation.

Author

Adrian Baddeley Adrian.Baddeley@curtin.edu.au, Rolf Turner rolfturner@posteo.net, Ege Rubak rubak@math.aau.dk, Tilman Davies Tilman.Davies@otago.ac.nz and Martin Hazelton Martin.Hazelton@otago.ac.nz.

Details

The inhomogeneous multitype (type \(i\) to any type) pair correlation function \(g_{i\bullet}(r)\) is a summary of the dependence between different types of points in a multitype spatial point process that does not have a uniform density of points.

The best intuitive interpretation is the following: the probability \(p(r)\) of finding a point of type \(i\) at location \(x\) and another point of any type at location \(y\), where \(x\) and \(y\) are separated by a distance \(r\), is equal to $$ p(r) = \lambda_i(x) lambda(y) g(r) \,{\rm d}x \, {\rm d}y $$ where \(\lambda_i\) is the intensity function of the process of points of type \(i\), and where \(\lambda\) is the intensity function of the points of all types. For a multitype Poisson point process, this probability is \(p(r) = \lambda_i(x) \lambda(y)\) so \(g_{i\bullet}(r) = 1\).

The command pcfdot.inhom estimates the inhomogeneous multitype pair correlation using a modified version of the algorithm in pcf.ppp. The arguments bw and adjust.bw control the degree of one-dimensional smoothing of the estimate of pair correlation.

If the arguments lambdaI and/or lambdadot are missing or null, they will be estimated from X by spatial kernel smoothing using a leave-one-out estimator, computed by density.ppp. Arguments such as sigma, varcov and adjust.sigma (passed to pcfmulti.inhom) control the degree of spatial smoothing.

See Also

pcf.ppp, pcfinhom, pcfdot, pcfcross.inhom

Examples

Run this code
  plot(pcfdot.inhom(amacrine, "on", stoyan=0.1), legendpos="bottom")

Run the code above in your browser using DataLab