| pcfmulti | R Documentation |
For a marked point pattern, estimate the multitype pair correlation function using kernel methods.
pcfmulti(X, I, J, ..., r = NULL, rmax=NULL,
adaptive=FALSE,
kernel = "epanechnikov", bw = NULL, h=NULL,
bw.args=list(), stoyan = 0.15, adjust=1,
correction = c("translate", "Ripley"),
divisor=c("a", "r", "d", "t"),
zerocor=c("convolution", "reflection", "bdrykern",
"JonesFoster", "weighted", "none",
"good", "best"),
nsmall = 300,
gref=NULL,
tau = 0,
Iname = "points satisfying condition I",
Jname = "points satisfying condition J",
IJexclusive=FALSE,
ratio = FALSE,
close=NULL)
X |
The observed point pattern,
from which an estimate of the multitype pair correlation function
|
I |
Subset index specifying the points of |
J |
Subset index specifying the points in |
... |
Ignored. |
r |
Vector of values for the argument |
rmax |
Optional. Maximum desired value of the argument |
adaptive |
Logical value specifying whether to use adaptive kernel smoothing
( |
kernel |
Choice of smoothing kernel,
passed to |
bw |
Bandwidth for smoothing kernel. Either a single numeric value giving the standard deviation of the kernel, or a character string specifying a bandwidth selection rule, or a function that computes the selected bandwidth. See Details. |
h |
Kernel halfwidth |
bw.args |
Optional. List of additional arguments to be passed to |
stoyan |
Coefficient for default bandwidth rule. |
adjust |
Numerical adjustment factor for the bandwidth.
The bandwidth actually used is |
correction |
String (partially matched) specifying the choice or choices
of spatial edge correction. Options include |
divisor |
String specifying the choice of estimator.
See |
zerocor |
String (partially matched) specifying a correction for the boundary effect
bias at |
nsmall |
Optional. Integer. The maximum number of data points
for which the default value of |
gref |
Optional. A pair correlation function that will be used as the
reference for the transformation to uniformity, when
|
tau |
Optional shrinkage coefficient. A single numeric value. |
Iname, Jname |
Optional. Character strings describing the members of
the subsets |
IJexclusive |
Logical value indicating whether the subsets |
ratio |
Logical.
If |
close |
Advanced use only. Precomputed data obtained from |
This is a generalisation of pcfcross
to arbitrary collections of points.
The algorithm measures the distance from each data point
in subset I to each data point in subset J,
excluding identical pairs of points. The distances are
kernel-smoothed and renormalised to form a pair correlation
function.
The smoothing algorithm is a multitype version of the
smoothing algorithm in pcf.ppp.
See pcf.ppp for detailed documentation of the arguments
correction, divisor, zerocor,
and other smoothing arguments.
An object of class "fv".
, \tilman and \martinH.
pcfcross,
pcfdot,
pcf.ppp.
adult <- (marks(longleaf) >= 30)
juvenile <- !adult
p <- pcfmulti(longleaf, adult, juvenile)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.