Learn R Programming

spatstat.explore (version 3.8-0)

pcfmulti: Marked pair correlation function

Description

For a marked point pattern, estimate the multitype pair correlation function using kernel methods.

Usage

pcfmulti(X, I, J, ..., r = NULL, rmax=NULL,
            adaptive=FALSE,
            kernel = "epanechnikov", bw = NULL, h=NULL,
            bw.args=list(), stoyan = 0.15, adjust=1,
            correction = c("translate", "Ripley"),
            divisor=c("a", "r", "d", "t"),
            zerocor=c("convolution", "reflection", "bdrykern",
                      "JonesFoster", "weighted", "none",
                      "good", "best"),
            nsmall = 300,
            gref=NULL,
            tau = 0,
            Iname = "points satisfying condition I",
            Jname = "points satisfying condition J",
            IJexclusive=FALSE,
            ratio = FALSE,
            close=NULL)

Arguments

Value

An object of class "fv".

Details

This is a generalisation of pcfcross to arbitrary collections of points.

The algorithm measures the distance from each data point in subset I to each data point in subset J, excluding identical pairs of points. The distances are kernel-smoothed and renormalised to form a pair correlation function.

The smoothing algorithm is a multitype version of the smoothing algorithm in pcf.ppp.

See pcf.ppp for detailed documentation of the arguments correction, divisor, zerocor, and other smoothing arguments.

See Also

pcfcross, pcfdot, pcf.ppp.

Examples

Run this code
  adult <- (marks(longleaf) >= 30)
  juvenile <- !adult
  p <- pcfmulti(longleaf, adult, juvenile)

Run the code above in your browser using DataLab